@@ -6,4 +6,6 @@
 
 // Export widget models and views, and the npm package version number.
 module.exports = require('./control.js');
+module.exports = require('./line.js');
+module.exports = require('./scatter.js');
 module.exports['version'] = require('../package.json').version;
